@@ -1,5 +1,6 @@
 # coding=utf-8
 import io
+from datetime import datetime
 
 import pkg_resources
 from PIL import Image, ImageDraw, ImageFont
@@ -27,7 +28,7 @@ def draw_longstring(draw, name, position):
     draw.text(position, name, font=font, fill=(0, 0, 0))
 
 
-def convert(name, date, a_hash, position, page_img, right_top=False):
+def generate_img(name: str, date: datetime, a_hash: str, position: str) -> io.BytesIO:
     sign_img = Image.new('RGBA', (WIDTH, HEIGHT), color=(255, 255, 255, 0))
 
     d = ImageDraw.Draw(sign_img)
@@ -42,12 +43,4 @@ def convert(name, date, a_hash, position, page_img, right_top=False):
     sign_img.save(sign_img_bytes, format='png')
     sign_img_bytes.seek(0)
 
-    if right_top:
-        page_img.paste(sign_img, (page_img.size[0] - WIDTH - 30, 0), sign_img)
-    else:
-        page_img.paste(sign_img, (30, page_img.size[1] - HEIGHT - 40), sign_img)
-    page_img_bytes = io.BytesIO()
-    page_img.save(page_img_bytes, format='pdf')
-    page_img_bytes.seek(0)
-
-    return page_img_bytes
+    return sign_img_bytes
